# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/managing_account.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/self_service/account/v0/managing_account.proto\x12\x1cqwak.self_service.account.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\x12\n\x10\x43loudProviderAWS\"\x12\n\x10\x43loudProviderGCP\"\xb3\x01\n\x11\x43loudProviderSpec\x12=\n\x03\x61ws\x18\x01 \x01(\x0b\x32..qwak.self_service.account.v0.CloudProviderAWSH\x00\x12=\n\x03gcp\x18\x02 \x01(\x0b\x32..qwak.self_service.account.v0.CloudProviderGCPH\x00\x12\x0e\n\x06region\x18\x03 \x01(\tB\x10\n\x0e\x63loud_provider\"\x98\x02\n\x14\x43reateAccountOptions\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12G\n\x0e\x63loud_provider\x18\x02 \x01(\x0e\x32+.qwak.self_service.account.v0.CloudProviderB\x02\x18\x01\x12L\n\x13\x63loud_provider_spec\x18\x03 \x01(\x0b\x32/.qwak.self_service.account.v0.CloudProviderSpec\x12S\n\x11jfrog_tenant_spec\x18\x04 \x01(\x0b\x32\x38.qwak.self_service.account.v0.SelfServiceJFrogTenantSpec\"\xff\x01\n\x1f\x43reateAccountRequestDescription\x12L\n\x08metadata\x18\x01 \x01(\x0b\x32:.qwak.self_service.account.v0.CreateAccountRequestMetadata\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x36.qwak.self_service.account.v0.CreateAccountRequestSpec\x12H\n\x06status\x18\x03 \x01(\x0b\x32\x38.qwak.self_service.account.v0.CreateAccountRequestStatus\"x\n\x1c\x43reateAccountRequestMetadata\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0crequested_by\x18\x03 \x01(\t\"0\n\x18\x43reateAccountRequestSpec\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\"\x9d\x01\n\x1a\x43reateAccountRequestStatus\x12J\n\x04\x63ode\x18\x01 \x01(\x0e\x32<.qwak.self_service.account.v0.CreateAccountRequestStatusCode\x12\x33\n\x0flast_changed_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"l\n\x14\x43loudProviderRegions\x12\x43\n\x0e\x63loud_provider\x18\x01 \x01(\x0e\x32+.qwak.self_service.account.v0.CloudProvider\x12\x0f\n\x07regions\x18\x02 \x03(\t\"2\n\x1bSelfServiceJFrogProjectSpec\x12\x13\n\x0bproject_key\x18\x01 \x01(\t\"u\n\x1aSelfServiceJFrogTenantSpec\x12W\n\x14\x64\x65\x66\x61ult_project_spec\x18\x01 \x01(\x0b\x32\x39.qwak.self_service.account.v0.SelfServiceJFrogProjectSpec*=\n\rCloudProvider\x12\x1a\n\x16\x43LOUD_PROVIDER_INVALID\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02*\xa9\x01\n\x1e\x43reateAccountRequestStatusCode\x12.\n*CREATE_ACCOUNT_REQUEST_STATUS_CODE_INVALID\x10\x00\x12\x13\n\x0fREQUEST_PENDING\x10\x01\x12\x16\n\x12REQUEST_REGISTERED\x10\x02\x12\x16\n\x12REQUEST_PROCESSING\x10\x03\x12\x12\n\x0eREQUEST_FAILED\x10\x04\x42\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')

_CLOUDPROVIDER = DESCRIPTOR.enum_types_by_name['CloudProvider']
CloudProvider = enum_type_wrapper.EnumTypeWrapper(_CLOUDPROVIDER)
_CREATEACCOUNTREQUESTSTATUSCODE = DESCRIPTOR.enum_types_by_name['CreateAccountRequestStatusCode']
CreateAccountRequestStatusCode = enum_type_wrapper.EnumTypeWrapper(_CREATEACCOUNTREQUESTSTATUSCODE)
CLOUD_PROVIDER_INVALID = 0
AWS = 1
GCP = 2
CREATE_ACCOUNT_REQUEST_STATUS_CODE_INVALID = 0
REQUEST_PENDING = 1
REQUEST_REGISTERED = 2
REQUEST_PROCESSING = 3
REQUEST_FAILED = 4


_CLOUDPROVIDERAWS = DESCRIPTOR.message_types_by_name['CloudProviderAWS']
_CLOUDPROVIDERGCP = DESCRIPTOR.message_types_by_name['CloudProviderGCP']
_CLOUDPROVIDERSPEC = DESCRIPTOR.message_types_by_name['CloudProviderSpec']
_CREATEACCOUNTOPTIONS = DESCRIPTOR.message_types_by_name['CreateAccountOptions']
_CREATEACCOUNTREQUESTDESCRIPTION = DESCRIPTOR.message_types_by_name['CreateAccountRequestDescription']
_CREATEACCOUNTREQUESTMETADATA = DESCRIPTOR.message_types_by_name['CreateAccountRequestMetadata']
_CREATEACCOUNTREQUESTSPEC = DESCRIPTOR.message_types_by_name['CreateAccountRequestSpec']
_CREATEACCOUNTREQUESTSTATUS = DESCRIPTOR.message_types_by_name['CreateAccountRequestStatus']
_CLOUDPROVIDERREGIONS = DESCRIPTOR.message_types_by_name['CloudProviderRegions']
_SELFSERVICEJFROGPROJECTSPEC = DESCRIPTOR.message_types_by_name['SelfServiceJFrogProjectSpec']
_SELFSERVICEJFROGTENANTSPEC = DESCRIPTOR.message_types_by_name['SelfServiceJFrogTenantSpec']
CloudProviderAWS = _reflection.GeneratedProtocolMessageType('CloudProviderAWS', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDPROVIDERAWS,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CloudProviderAWS)
  })
_sym_db.RegisterMessage(CloudProviderAWS)

CloudProviderGCP = _reflection.GeneratedProtocolMessageType('CloudProviderGCP', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDPROVIDERGCP,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CloudProviderGCP)
  })
_sym_db.RegisterMessage(CloudProviderGCP)

CloudProviderSpec = _reflection.GeneratedProtocolMessageType('CloudProviderSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDPROVIDERSPEC,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CloudProviderSpec)
  })
_sym_db.RegisterMessage(CloudProviderSpec)

CreateAccountOptions = _reflection.GeneratedProtocolMessageType('CreateAccountOptions', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTOPTIONS,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountOptions)
  })
_sym_db.RegisterMessage(CreateAccountOptions)

CreateAccountRequestDescription = _reflection.GeneratedProtocolMessageType('CreateAccountRequestDescription', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUESTDESCRIPTION,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountRequestDescription)
  })
_sym_db.RegisterMessage(CreateAccountRequestDescription)

CreateAccountRequestMetadata = _reflection.GeneratedProtocolMessageType('CreateAccountRequestMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUESTMETADATA,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountRequestMetadata)
  })
_sym_db.RegisterMessage(CreateAccountRequestMetadata)

CreateAccountRequestSpec = _reflection.GeneratedProtocolMessageType('CreateAccountRequestSpec', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUESTSPEC,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountRequestSpec)
  })
_sym_db.RegisterMessage(CreateAccountRequestSpec)

CreateAccountRequestStatus = _reflection.GeneratedProtocolMessageType('CreateAccountRequestStatus', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUESTSTATUS,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CreateAccountRequestStatus)
  })
_sym_db.RegisterMessage(CreateAccountRequestStatus)

CloudProviderRegions = _reflection.GeneratedProtocolMessageType('CloudProviderRegions', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDPROVIDERREGIONS,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.CloudProviderRegions)
  })
_sym_db.RegisterMessage(CloudProviderRegions)

SelfServiceJFrogProjectSpec = _reflection.GeneratedProtocolMessageType('SelfServiceJFrogProjectSpec', (_message.Message,), {
  'DESCRIPTOR' : _SELFSERVICEJFROGPROJECTSPEC,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.SelfServiceJFrogProjectSpec)
  })
_sym_db.RegisterMessage(SelfServiceJFrogProjectSpec)

SelfServiceJFrogTenantSpec = _reflection.GeneratedProtocolMessageType('SelfServiceJFrogTenantSpec', (_message.Message,), {
  'DESCRIPTOR' : _SELFSERVICEJFROGTENANTSPEC,
  '__module__' : 'qwak.self_service.account.v0.managing_account_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.account.v0.SelfServiceJFrogTenantSpec)
  })
_sym_db.RegisterMessage(SelfServiceJFrogTenantSpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _CREATEACCOUNTOPTIONS.fields_by_name['cloud_provider']._options = None
  _CREATEACCOUNTOPTIONS.fields_by_name['cloud_provider']._serialized_options = b'\030\001'
  _CLOUDPROVIDER._serialized_start=1494
  _CLOUDPROVIDER._serialized_end=1555
  _CREATEACCOUNTREQUESTSTATUSCODE._serialized_start=1558
  _CREATEACCOUNTREQUESTSTATUSCODE._serialized_end=1727
  _CLOUDPROVIDERAWS._serialized_start=118
  _CLOUDPROVIDERAWS._serialized_end=136
  _CLOUDPROVIDERGCP._serialized_start=138
  _CLOUDPROVIDERGCP._serialized_end=156
  _CLOUDPROVIDERSPEC._serialized_start=159
  _CLOUDPROVIDERSPEC._serialized_end=338
  _CREATEACCOUNTOPTIONS._serialized_start=341
  _CREATEACCOUNTOPTIONS._serialized_end=621
  _CREATEACCOUNTREQUESTDESCRIPTION._serialized_start=624
  _CREATEACCOUNTREQUESTDESCRIPTION._serialized_end=879
  _CREATEACCOUNTREQUESTMETADATA._serialized_start=881
  _CREATEACCOUNTREQUESTMETADATA._serialized_end=1001
  _CREATEACCOUNTREQUESTSPEC._serialized_start=1003
  _CREATEACCOUNTREQUESTSPEC._serialized_end=1051
  _CREATEACCOUNTREQUESTSTATUS._serialized_start=1054
  _CREATEACCOUNTREQUESTSTATUS._serialized_end=1211
  _CLOUDPROVIDERREGIONS._serialized_start=1213
  _CLOUDPROVIDERREGIONS._serialized_end=1321
  _SELFSERVICEJFROGPROJECTSPEC._serialized_start=1323
  _SELFSERVICEJFROGPROJECTSPEC._serialized_end=1373
  _SELFSERVICEJFROGTENANTSPEC._serialized_start=1375
  _SELFSERVICEJFROGTENANTSPEC._serialized_end=1492
# @@protoc_insertion_point(module_scope)
